@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     DeploymentStatusType,
@@ -291,7 +291,7 @@ _OptionalCreateEnvironmentInputRequestTypeDef = TypedDict(
         "description": str,
         "environmentAccountConnectionId": str,
         "protonServiceRoleArn": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
         "templateMinorVersion": str,
     },
     total=False,
@@ -325,7 +325,7 @@ _OptionalCreateEnvironmentTemplateInputRequestTypeDef = TypedDict(
         "displayName": str,
         "encryptionKey": str,
         "provisioning": Literal["CUSTOMER_MANAGED"],
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -359,7 +359,7 @@ _OptionalCreateEnvironmentTemplateVersionInputRequestTypeDef = TypedDict(
         "clientToken": str,
         "description": str,
         "majorVersion": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -396,7 +396,7 @@ _OptionalCreateServiceInputRequestTypeDef = TypedDict(
         "description": str,
         "repositoryConnectionArn": str,
         "repositoryId": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
         "templateMinorVersion": str,
     },
     total=False,
@@ -430,7 +430,7 @@ _OptionalCreateServiceTemplateInputRequestTypeDef = TypedDict(
         "displayName": str,
         "encryptionKey": str,
         "pipelineProvisioning": Literal["CUSTOMER_MANAGED"],
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -454,7 +454,7 @@ CreateServiceTemplateOutputTypeDef = TypedDict(
 _RequiredCreateServiceTemplateVersionInputRequestTypeDef = TypedDict(
     "_RequiredCreateServiceTemplateVersionInputRequestTypeDef",
     {
-        "compatibleEnvironmentTemplates": List["CompatibleEnvironmentTemplateInputTypeDef"],
+        "compatibleEnvironmentTemplates": Sequence["CompatibleEnvironmentTemplateInputTypeDef"],
         "source": "TemplateVersionSourceInputTypeDef",
         "templateName": str,
     },
@@ -465,7 +465,7 @@ _OptionalCreateServiceTemplateVersionInputRequestTypeDef = TypedDict(
         "clientToken": str,
         "description": str,
         "majorVersion": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -960,7 +960,7 @@ _OptionalListEnvironmentAccountConnectionsInputRequestTypeDef = TypedDict(
         "environmentName": str,
         "maxResults": int,
         "nextToken": str,
-        "statuses": List[EnvironmentAccountConnectionStatusType],
+        "statuses": Sequence[EnvironmentAccountConnectionStatusType],
     },
     total=False,
 )
@@ -1036,7 +1036,7 @@ ListEnvironmentTemplatesOutputTypeDef = TypedDict(
 ListEnvironmentsInputRequestTypeDef = TypedDict(
     "ListEnvironmentsInputRequestTypeDef",
     {
-        "environmentTemplates": List["EnvironmentTemplateFilterTypeDef"],
+        "environmentTemplates": Sequence["EnvironmentTemplateFilterTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1475,7 +1475,7 @@ TagResourceInputRequestTypeDef = TypedDict(
     "TagResourceInputRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1499,7 +1499,7 @@ UntagResourceInputRequestTypeDef = TypedDict(
     "UntagResourceInputRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -1773,7 +1773,7 @@ _RequiredUpdateServiceTemplateVersionInputRequestTypeDef = TypedDict(
 _OptionalUpdateServiceTemplateVersionInputRequestTypeDef = TypedDict(
     "_OptionalUpdateServiceTemplateVersionInputRequestTypeDef",
     {
-        "compatibleEnvironmentTemplates": List["CompatibleEnvironmentTemplateInputTypeDef"],
+        "compatibleEnvironmentTemplates": Sequence["CompatibleEnvironmentTemplateInputTypeDef"],
         "description": str,
         "status": TemplateVersionStatusType,
     },
